@@ -1,4 +1,6 @@
+pub use aggregate::Aggregate;
 pub use aggregate_type::AggregateType;
+pub use aggregate_channel::AggregateChannel;
 pub use combined_event::CombinedEvent;
 pub use command::Command;
 pub use command_message::CommandMessage;
@@ -9,7 +11,9 @@ pub use multi_stream_topic::MultiStreamTopic;
 pub use pg_repository::PgRepository;
 pub use stream_topic::StreamTopic;
 
+mod aggregate;
 mod aggregate_type;
+mod aggregate_channel;
 mod combined_event;
 mod command;
 mod command_message;
